﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace HowDoICodeFirst.Annotations.Models
{
    [Table("InternalBlogs")]
    public class Blog
    {
        [Key]
        public int PrimaryTrackingKey { get; set; }
        [Required]
        public string Title { get; set; }
        [MaxLength(10,ErrorMessage="BloggerName must be 10 characters or less"),MinLength(5)]
        public string BloggerName { get; set; }

        [Timestamp]
        public Byte[] TimeStamp { get; set; }

        public BlogDetails BlogDetail { get; set; }
        public virtual ICollection<Post> Posts { get; set; }

        [NotMapped]
        public string BlogCode
        {
            get
            {
                return Title.Substring(0, 1) + ":" + BloggerName.Substring(0, 1);
            }
        }
    }

    [ComplexType]
    public class BlogDetails
    {
        public DateTime? DateCreated {get;set;}
        [MaxLength(250),Column("BlogDescription", TypeName="ntext")]
        public string Description{get;set;}
    }

    public class Post
    {
        public int Id { get; set; }
        public string Title { get; set; }
        public DateTime DateCreated { get; set; }
        public string Content { get; set; }
        public int BlogId { get; set; }

        public Person CreatedBy { get; set; }
        public Person UpdatedBy { get; set; }

        [ForeignKey("BlogId")]
        public Blog Blog { get; set; }
        public ICollection<Comment> Comments { get; set; }

    }
    public class Person
    {
        public int Id { get; set; }
        public string Name { get; set; }

        [InverseProperty("CreatedBy")]
        public List<Post> PostsWritten { get; set; }
        [InverseProperty("UpdatedBy")]
        public List<Post> PostsUpdated { get; set; }
    }


    public class Comment
    {

        public int Id { get; set; }
        public DateTime DateCreated { get; set; }
        public string Content { get; set; }
        public int PostId { get; set; }

        //navigation back to parent
        public Post Post { get; set; }
    }
}